(function (M0,M1,M2,M3,M4,M5,XX) {
/**
 * @preserve (C) 2000 - 2020 Nebular Streams - All Rights Reserved.
 */


(function(
    PROMISE,
    ObjectAssign,
    ObjectKeys,
    window_setTimeout,
    window_clearTimeout,
    window_location,
    window_addEventListener,
    DOC,
    BODY,
    HTML,
    HTMLCLASS,
    WINDOW,
    NIP,
    ERROR
) {

const
    D = false,
    Promise_resolve = PROMISE.resolve,
    Promise_reject = PROMISE.reject;

/* eslint-disable no-unused-vars,no-use-before-define */

function md5(input) {
	// FLOW: input -> utf8 input -> bin input -> bin md5 -> utf8 md5 -> hex md5
	var
		hex_vocab = "0123456789abcdef",

		raw_input = "",
		raw_input_bits_len,
		bin_input,
		bin_md5,
		raw_md5 = "",
		hex_md5 = "",

		i = -1,
		x,
		y;


	function safe_add(x, y) {
		var lsw = (x & 0xFFFF) + (y & 0xFFFF);
		return (((x >> 16) + (y >> 16) + (lsw >> 16)) << 16) | (lsw & 0xFFFF);
	}

	// basic operations
	function cmn(q, a, b, x, s, t) {
		var num = safe_add(safe_add(a, q), safe_add(x, t));
		return safe_add((num << s) | (num >>> (32 - s)), b);
	}

	function ff(a, b, c, d, x, s, t) {
		return cmn((b & c) | ((~b) & d), a, b, x, s, t);
	}

	function gg(a, b, c, d, x, s, t) {
		return cmn((b & d) | (c & (~d)), a, b, x, s, t);
	}

	function hh(a, b, c, d, x, s, t) {
		return cmn(b ^ c ^ d, a, b, x, s, t);
	}

	function ii(a, b, c, d, x, s, t) {
		return cmn(c ^ (b | (~d)), a, b, x, s, t);
	}


	// encode string to utf-8
	while (++i < input.length) {
		// decode utf-16 surrogate pairs
		x = input.charCodeAt(i);
		y = i + 1 < input.length ? input.charCodeAt(i + 1) : 0;
		if (0xD800 <= x && x <= 0xDBFF && 0xDC00 <= y && y <= 0xDFFF) {
			x = 0x10000 + ((x & 0x03FF) << 10) + (y & 0x03FF);
			i++;
		}

		// encode raw_input as utf-8
		if (x <= 0x7F) {
			raw_input += String.fromCharCode(x);
		} else if (x <= 0x7FF) {
			raw_input += String.fromCharCode(0xC0 | ((x >>> 6) & 0x1F),
				0x80 | (x & 0x3F));
		} else if (x <= 0xFFFF) {
			raw_input += String.fromCharCode(0xE0 | ((x >>> 12) & 0x0F),
				0x80 | ((x >>> 6) & 0x3F),
				0x80 | (x & 0x3F));
		} else if (x <= 0x1FFFFF) {
			raw_input += String.fromCharCode(0xF0 | ((x >>> 18) & 0x07),
				0x80 | ((x >>> 12) & 0x3F),
				0x80 | ((x >>> 6) & 0x3F),
				0x80 | (x & 0x3F));
		}
	}


	// number of bits in the raw utf-8 string
	raw_input_bits_len = raw_input.length * 8;


	// string to little-endian array words
	bin_input = new Array(raw_input.length >> 2);
	for (i = 0; i < bin_input.length; i++) {
		bin_input[i] = 0;
	}
	for (i = 0; i < raw_input_bits_len; i += 8) {
		bin_input[i >> 5] |= (raw_input.charCodeAt(i / 8) & 0xFF) << (i % 32);
	}


	// calculate md5 as little-endian array words
	// padding
	bin_input[raw_input_bits_len >> 5] |= 0x80 << ((raw_input_bits_len) % 32);
	bin_input[(((raw_input_bits_len + 64) >>> 9) << 4) + 14] = raw_input_bits_len;

	var
		a = 1732584193,
		b = -271733879,
		c = -1732584194,
		d = 271733878;

	for (i = 0; i < bin_input.length; i += 16) {
		var
			olda = a,
			oldb = b,
			oldc = c,
			oldd = d;

		a = ff(a, b, c, d, bin_input[i], 7, -680876936);
		d = ff(d, a, b, c, bin_input[i + 1], 12, -389564586);
		c = ff(c, d, a, b, bin_input[i + 2], 17, 606105819);
		b = ff(b, c, d, a, bin_input[i + 3], 22, -1044525330);
		a = ff(a, b, c, d, bin_input[i + 4], 7, -176418897);
		d = ff(d, a, b, c, bin_input[i + 5], 12, 1200080426);
		c = ff(c, d, a, b, bin_input[i + 6], 17, -1473231341);
		b = ff(b, c, d, a, bin_input[i + 7], 22, -45705983);
		a = ff(a, b, c, d, bin_input[i + 8], 7, 1770035416);
		d = ff(d, a, b, c, bin_input[i + 9], 12, -1958414417);
		c = ff(c, d, a, b, bin_input[i + 10], 17, -42063);
		b = ff(b, c, d, a, bin_input[i + 11], 22, -1990404162);
		a = ff(a, b, c, d, bin_input[i + 12], 7, 1804603682);
		d = ff(d, a, b, c, bin_input[i + 13], 12, -40341101);
		c = ff(c, d, a, b, bin_input[i + 14], 17, -1502002290);
		b = ff(b, c, d, a, bin_input[i + 15], 22, 1236535329);

		a = gg(a, b, c, d, bin_input[i + 1], 5, -165796510);
		d = gg(d, a, b, c, bin_input[i + 6], 9, -1069501632);
		c = gg(c, d, a, b, bin_input[i + 11], 14, 643717713);
		b = gg(b, c, d, a, bin_input[i], 20, -373897302);
		a = gg(a, b, c, d, bin_input[i + 5], 5, -701558691);
		d = gg(d, a, b, c, bin_input[i + 10], 9, 38016083);
		c = gg(c, d, a, b, bin_input[i + 15], 14, -660478335);
		b = gg(b, c, d, a, bin_input[i + 4], 20, -405537848);
		a = gg(a, b, c, d, bin_input[i + 9], 5, 568446438);
		d = gg(d, a, b, c, bin_input[i + 14], 9, -1019803690);
		c = gg(c, d, a, b, bin_input[i + 3], 14, -187363961);
		b = gg(b, c, d, a, bin_input[i + 8], 20, 1163531501);
		a = gg(a, b, c, d, bin_input[i + 13], 5, -1444681467);
		d = gg(d, a, b, c, bin_input[i + 2], 9, -51403784);
		c = gg(c, d, a, b, bin_input[i + 7], 14, 1735328473);
		b = gg(b, c, d, a, bin_input[i + 12], 20, -1926607734);

		a = hh(a, b, c, d, bin_input[i + 5], 4, -378558);
		d = hh(d, a, b, c, bin_input[i + 8], 11, -2022574463);
		c = hh(c, d, a, b, bin_input[i + 11], 16, 1839030562);
		b = hh(b, c, d, a, bin_input[i + 14], 23, -35309556);
		a = hh(a, b, c, d, bin_input[i + 1], 4, -1530992060);
		d = hh(d, a, b, c, bin_input[i + 4], 11, 1272893353);
		c = hh(c, d, a, b, bin_input[i + 7], 16, -155497632);
		b = hh(b, c, d, a, bin_input[i + 10], 23, -1094730640);
		a = hh(a, b, c, d, bin_input[i + 13], 4, 681279174);
		d = hh(d, a, b, c, bin_input[i], 11, -358537222);
		c = hh(c, d, a, b, bin_input[i + 3], 16, -722521979);
		b = hh(b, c, d, a, bin_input[i + 6], 23, 76029189);
		a = hh(a, b, c, d, bin_input[i + 9], 4, -640364487);
		d = hh(d, a, b, c, bin_input[i + 12], 11, -421815835);
		c = hh(c, d, a, b, bin_input[i + 15], 16, 530742520);
		b = hh(b, c, d, a, bin_input[i + 2], 23, -995338651);

		a = ii(a, b, c, d, bin_input[i], 6, -198630844);
		d = ii(d, a, b, c, bin_input[i + 7], 10, 1126891415);
		c = ii(c, d, a, b, bin_input[i + 14], 15, -1416354905);
		b = ii(b, c, d, a, bin_input[i + 5], 21, -57434055);
		a = ii(a, b, c, d, bin_input[i + 12], 6, 1700485571);
		d = ii(d, a, b, c, bin_input[i + 3], 10, -1894986606);
		c = ii(c, d, a, b, bin_input[i + 10], 15, -1051523);
		b = ii(b, c, d, a, bin_input[i + 1], 21, -2054922799);
		a = ii(a, b, c, d, bin_input[i + 8], 6, 1873313359);
		d = ii(d, a, b, c, bin_input[i + 15], 10, -30611744);
		c = ii(c, d, a, b, bin_input[i + 6], 15, -1560198380);
		b = ii(b, c, d, a, bin_input[i + 13], 21, 1309151649);
		a = ii(a, b, c, d, bin_input[i + 4], 6, -145523070);
		d = ii(d, a, b, c, bin_input[i + 11], 10, -1120210379);
		c = ii(c, d, a, b, bin_input[i + 2], 15, 718787259);
		b = ii(b, c, d, a, bin_input[i + 9], 21, -343485551);

		a = safe_add(a, olda);
		b = safe_add(b, oldb);
		c = safe_add(c, oldc);
		d = safe_add(d, oldd);
	}
	bin_md5 = [a, b, c, d];


	// little-endian array words to a string
	for (i = 0; i < bin_md5.length * 32; i += 8) {
		raw_md5 += String.fromCharCode((bin_md5[i >> 5] >>> (i % 32)) & 0xFF);
	}


	// convert the raw md5 string to a hex md5 string
	for (i = 0; i < raw_md5.length; i++) {
		x = raw_md5.charCodeAt(i);
		hex_md5 += hex_vocab.charAt((x >>> 4) & 0x0F) + hex_vocab.charAt(x & 0x0F);
	}

	return hex_md5;
}

function Requirer() {

	const globals = typeof window === "undefined" ? global : window;
	if  (typeof globals.require === "function") return globals.require;

	const
		modules = {},
		cache = {},
		aliases = {},
		has = ({}).hasOwnProperty;


	// eslint-disable-next-line no-underscore-dangle
	const _cmp = "components/";

	function unalias(alias, loaderPath) {
		let start = 0;
		if (loaderPath) {
			if (loaderPath.indexOf(_cmp) === 0) {
				start = _cmp.length;
			}
			if (loaderPath.indexOf("/", start) > 0) {
				loaderPath = loaderPath.substring(start, loaderPath.indexOf("/", start));
			}
		}

		const result = aliases[alias + "/index.js"] || aliases[loaderPath + "/deps/" + alias + "/index.js"];
		if (result) {
			return _cmp + result.substring(0, result.length - ".js".length);
		}
		return alias;
	}

	// eslint-disable-next-line no-underscore-dangle
	const _reg = /^\.\.?(\/|$)/;

	function expand(root, name) {

		let part;

		const
			results = [],
			parts = (_reg.test(name) ? root + "/" + name : name).split("/");

		for (let i = 0, length = parts.length; i < length; i++) {
			part = parts[i];
			if (part === "..") {
				results.pop();
			} else if (part !== "." && part !== "") {
				results.push(part);
			}
		}
		return results.join("/");
	}

	function dirname(path) {
		return path.split("/")
			.slice(0, -1)
			.join("/");
	}

	function requireInternal(name, loaderPath) {

		if (loaderPath == null) loaderPath = "/";
		const path = unalias(name, loaderPath);

		if (has.call(cache, path)) return cache[path].exports;
		if (has.call(modules, path)) return initModule(path, modules[path]);


		const namemd5 = md5(name);
		const pathmd5 = unalias(namemd5, loaderPath);

		if (has.call(cache, pathmd5)) return cache[pathmd5].exports;
		if (has.call(modules, pathmd5)) return initModule(pathmd5, modules[pathmd5]);


		let dirIndex = expand(path, "./index");
		if (has.call(cache, dirIndex)) return cache[dirIndex].exports;
		if (has.call(modules, dirIndex)) return initModule(dirIndex, modules[dirIndex]);


		dirIndex = expand(pathmd5, "./index");
		if (has.call(cache, dirIndex)) return cache[dirIndex].exports;
		if (has.call(modules, dirIndex)) return initModule(dirIndex, modules[dirIndex]);

		throw new Error("Cannot find module \"" + name + "\" from " + "\"" + loaderPath + "\"");
	}

	function localRequire(path) {
		return function expanded(name) {
			const absolute = expand(dirname(path), name);
			return requireInternal(absolute, path);
		};
	}

	function initModule(name, definition) {

		const module = {
			id: name,
			exports: {}
		};

		cache[name] = module;
		definition(module.exports, localRequire(name), module);
		return module.exports;

	}


	requireInternal.alias = function (from, to) {
		aliases[to] = from;
	};

	requireInternal.register = requireInternal.define = function (bundle, fn) {
		if (typeof bundle === "object") {
			for (const key in bundle) {
				if (has.call(bundle, key)) {
					modules[key] = bundle[key];
				}
			}
		} else {
			modules[bundle] = fn;
		}
	};

	requireInternal.list = function () {
		const result = [];
		for (const item in modules) {
			if (has.call(modules, item)) {
				result.push(item);
			}
		}
		return result;
	};

	requireInternal.brunch = true;
	requireInternal._cache = cache;

	globals.require = requireInternal;

	return requireInternal;
}

const
	require = Requirer(),
	requireRegister = require.register,
	requireDefine = require.define;
requireRegister(M0, function (exports, require, module) {
if (typeof Element.prototype.clearChildren === "undefined") {
	Object.defineProperty(Element.prototype, "clearChildren", {
		configurable: true,
		enumerable: false,
		value: () => {
			while (this.firstChild) this.removeChild(this.lastChild);
		}
	});
}

});
requireRegister(M1, function (exports, require, module) {
/* eslint-disable max-len,no-underscore-dangle */
/* global PROMISE, D, firebase,  Promise_reject */

const
	NobjAuth = require("nobj-auth"),
	ErrorHandler = require("errorhandler"),
	ErrorThrower = new ErrorHandler(
		[
			"Not connected",
			"No channel id",
			"Wrong root collection",
			"Already logging in!",
			"wrong authpack",
			"Channel was already activated"
		],
		true
	),

	ERROR_NO_FIRESTORE = 0,
	ERROR_NO_SYSNAME = 1,
	ERROR_BAD_ROOT = 2,
	ERROR_ALREADY_LOGGING_IN = 3,
	ERROR_WRONG_AUTHPACK = 4,
	ERROR_ALREADY_ACTIVATED = 5;


function FireApi(authPack) {

	// noinspection JSUnusedLocalSymbols
	const
		TAG = "[FirestoreApi]",
		ROOTCONTAINER_PRIVATE = "channels",
		ROOTCONTAINER_PUBLIC = "public",
		ROOTCONTAINER_ROOT = "root",

		COL_PRIVATE = 0,
		COL_PUBLIC = 1,
		COL_ROOT = 2,

		STRINGS = ["added", "modified", "removed"],
		SETTINGS = {

			/* your settings... */
			timestampsInSnapshots: true

		},

		mListeners = {};

	let mConnectedUserId = null,
		mActiveChannel = null,
		mChanQuery = null,
		mChanQueryPublic = null,
		mChanQueryRoot = null,
		mWorking = false,
		mDb;


	function loginFirestorePromise() {

		if (mWorking) {
			return Promise_reject.call(PROMISE, ErrorThrower(ERROR_ALREADY_LOGGING_IN));
		}

		return new PROMISE((resolve, reject) => {

			const
				FIREBASE = firebase;

			try {

				/*
				{
					"ext": {
						"src": "fbk",
						"fnm": "Rudolf Pintor",
						"ftk": "EAAX0USZATHOMBAJrCxoX1wWTXdECdNar3JAZCGnjdTDL02L0Rih97tmlLQArhe5hFZB0c1HcrSpsPvU4ZBelw1q8OYqMeJt76uimYOHB9zolc6oW0Y8yQEYSZCzg6AFZABMIhwFNPPk8HPCiftFQb01NNV2JmZBO2ZBVLfHpmkvusAZDZD",
						"FIRE": {
							"projectId": "nobj-quarantune",
						}
					},
					"exp": 1585528712185,
					"iss": "NANO",
					"aud": "SOCIAL",
					"sub": "1198292656884105"
				}
				*/

				if (authPack.ext.fbtoken) {

					if (mConnectedUserId === authPack.sub && mDb) {
						resolve(false);
					} else {
						try {

							mWorking = true;
							mConnectedUserId = null;

							// noinspection JSUnresolvedFunction
							FIREBASE
								.auth()
								.signInWithCustomToken(authPack.ext.fbtoken)
								.then(() => {
									mWorking = false;
									mConnectedUserId = authPack.sub;
									// noinspection JSUnresolvedFunction
									mDb = FIREBASE.firestore();
									mDb.settings(SETTINGS);
									resolve(true);
								})
								.catch((error) => {
									mWorking = false;
									mConnectedUserId = null;
									reject(error);
								});
						} catch (e) {
							mWorking = false;
							mConnectedUserId = null;
							reject(e);
						}
					}
				} else {
					reject(ErrorThrower(ERROR_WRONG_AUTHPACK));
				}
			} catch (e) {
				reject(e);
			}
		});
	}

	function refreshFbTokenPromise() {

		return new PROMISE(
			(resolve, reject) => {

				if (mConnectedUserId) {

					resolve(false);

				} else if (authPack && authPack.ext.fbtoken) {

					loginFirestorePromise(authPack)
						.then(resolve)
						.catch(reject);

				} else {

					// noinspection JSUnresolvedFunction
					NobjAuth.refresh("fs")
						.then(
							newAuthPack => loginFirestorePromise(newAuthPack)
								.then(resolve)
								.catch(reject)
						)
						.catch(reject);

				}
			}
		);
	}

	function rdoc(path) {
		return mDb.doc(path);
	}

	function rcol(path) {
		// noinspection JSUnresolvedFunction
		return mDb.collection(path);
	}


	/**
	 * Channel Querier
	 *
	 * @param SYSNAME
	 * @param ROOTCONTAINER
	 * @return {{ccol: (function(*=, *=): *), cdoc: (function(): *), sdoc: (function(*): *), listen: (function(*=, *=, *=, *=, *=)), Listener: (function(*=, *=): {start: start, stop: stop})}}
	 * @constructor
	 */
	function ChannelQuery(SYSNAME, ROOTCONTAINER) {

		if (!mDb) ErrorThrower(ERROR_NO_FIRESTORE, true);
		if (!SYSNAME) ErrorThrower(ERROR_NO_SYSNAME, true);

		let isRoot = false;
		ROOTCONTAINER = ROOTCONTAINER || ROOTCONTAINER_PRIVATE;

		switch (ROOTCONTAINER) {
			case ROOTCONTAINER_PUBLIC:
			case ROOTCONTAINER_PRIVATE:
				break;
			case ROOTCONTAINER_ROOT:
				isRoot = true;
				ROOTCONTAINER = null;
				break;
			default:
				ErrorThrower(ERROR_BAD_ROOT, true);
		}


		function getChannelFirestorePath(subpath) {
			return ROOTCONTAINER + "/" + SYSNAME + (subpath ? "/" + subpath : "");
		}

		function getChannelDocumentPath() {
			return getChannelFirestorePath();
		}

		function resolveCollectionPath(relativeCollectionName) {
			return isRoot ? relativeCollectionName : getChannelFirestorePath(relativeCollectionName);
		}

		function getFirestoreCollection(collectionName, queryEnhancer) {

			if (!mDb) ErrorThrower(ERROR_NO_FIRESTORE, true);
			// noinspection JSUnresolvedFunction
			const col = mDb.collection(resolveCollectionPath(collectionName));
			return (queryEnhancer && typeof queryEnhancer === "function")
				? queryEnhancer(col) : col;
		}


		/**
		 * @private
		 * @throws ERROR_NO_FIRESTORE
		 */

		function unregisterListener(name) {
			if (!mConnectedUserId) {
				ErrorThrower(ERROR_NO_FIRESTORE, true);
			}
			const handler = mListeners[mActiveChannel + ":" + name];
			if (handler && typeof handler === "function") {
				try {
					mListeners[mActiveChannel + name]();
					mListeners[mActiveChannel + name] = null;
					return true;
				} catch (e) {
					if (D) window.console.log(TAG, e.message);
				}
			}
			return false;
		}

		function registerListener(name, handler) {
			mListeners[mActiveChannel + ":" + name] = handler;
		}

		/**
		 * @private
		 * @throws ERROR_NO_FIRESTORE
		 */

		function collectionListen(chanCollection, queryEnhancer, changeListener) {

			if (!mConnectedUserId) {
				ErrorThrower(ERROR_NO_FIRESTORE, true);
			}

			unregisterListener(chanCollection);

			// noinspection JSUnresolvedFunction
			registerListener(
				chanCollection,
				getFirestoreCollection(chanCollection, queryEnhancer)
					.onSnapshot(
						snapshot => snapshot.docChanges()
							.forEach(changeListener, snapshot),
						(error) => {
							if (D) window.console.log(TAG, "error getting snapshots", error);
						}
					)
			);
		}

		function DocListener(docref) {

			// noinspection JSUnresolvedVariable
			const KEY = docref._key.path.toString();

			/**
			 * @throws ERROR_NO_FIRESTORE
			 */
			function stop() {
				// _path = docref._key.path.toString(),
				// _id = docref.id;

				unregisterListener(KEY);
			}

			/**
			 * @throws ERROR_NO_FIRESTORE
			 */

			function start(listener) {

				// noinspection JSUnresolvedFunction
				registerListener(
					KEY,
					docref.onSnapshot(
						{
							// Listen for document metadata changes
							includeMetadataChanges: true
						},
						(doc) => {

							const
								item = doc.data();

							// noinspection JSUnresolvedVariable
							item._path = doc._key.path.toString();
							item._id = doc.id;

							listener.notifyChange(item);

						}
					)
				);
			}

			return {
				start,
				stop
			};
		}


		function ChannelCollectionListener(collection, queryEnhancer) {

			/**
			 * @throws ERROR_NO_FIRESTORE
			 */
			function stop() {
				unregisterListener(collection);
			}

			/**
			 * @throws ERROR_NO_FIRESTORE
			 */

			function start(listener) {
				collectionListen(
					collection,
					queryEnhancer,
					(change) => {

						const
							{doc} = change,
							item = doc.data();

						// noinspection JSUnresolvedVariable
						item._path = doc._key.path.toString();
						item._id = doc.id;

						switch (change.type) {
							case STRINGS[0]: // "added"
								listener.notifyItemAdded(item);
								break;
							case STRINGS[1]: // "modified":
								listener.notifyItemModified(item);
								break;
							case STRINGS[2]: // "removed":
								listener.notifyItemRemoved(item);
								break;
							default:
							// unhandled event
						}
					}
				);
			}

			return {
				start,
				stop
			};
		}


		function listenPromise(collectionName, idField, aCondition, orderBy, listener) {
			return new PROMISE((resolve, reject) => {

				try {

					const
						chanCol = ChannelCollectionListener(
							collectionName,
							idField || "id",
							(query) => {

								if (isRoot) {
									query = query.where("channelInfo.id", "==", SYSNAME);
								}

								if (aCondition) {
									query = query.where(aCondition[0], aCondition[1], aCondition[2]);
								}

								if (orderBy) {
									query = query.orderBy(orderBy);
								}

								return query;
							}
						);
					chanCol.start(listener);
					resolve(collectionName);
				} catch (e) {
					reject(e);
				}
			});
		}

		return {
			/** channel collection */
			ccol: getFirestoreCollection,
			cdoc: () => rdoc(getChannelDocumentPath()),
			sdoc: service => rdoc(getChannelFirestorePath("services/" + service)),

			listen: listenPromise,

			/** realtime collection */
			Listener: ChannelCollectionListener,

			DocListener

		};
	}

	function setActiveChannel(channel) {
		if (mActiveChannel) ErrorThrower(ERROR_ALREADY_ACTIVATED, true);
		mActiveChannel = channel || mConnectedUserId;
		mChanQuery = new ChannelQuery(mActiveChannel, "channels");
		mChanQueryPublic = new ChannelQuery(mActiveChannel, "public");
		mChanQueryRoot = new ChannelQuery(mActiveChannel, "root");
	}

	// noinspection JSUnusedGlobalSymbols
	return {

		init: loginFirestorePromise,

		refresh: refreshFbTokenPromise,

		/** Root FS document */
		rdoc,

		/** root collection */
		rcol,

		current: (type) => {
			switch (type) {

				case COL_ROOT:
					return mChanQueryRoot;

				case COL_PUBLIC:
				case true:
					return mChanQueryPublic;

				case COL_PRIVATE:
				case false:
				default:
					return mChanQuery;
			}
		},
		getConnected: () => mConnectedUserId,
		getActive: () => mActiveChannel,
		channel: ChannelQuery,
		isOwner: () => mConnectedUserId && mConnectedUserId === mActiveChannel,
		setActiveChannel
	};
}

module.exports = FireApi;

});
requireRegister(M2, function (exports, require, module) {
// noinspection JSUnusedGlobalSymbols
/* eslint-disable no-underscore-dangle */

/* global PROMISE, NIP, ERROR, D, Promise_resolve, Promise_reject */

const
	NobjAuth = require("nobj.auth"),
	ErrorHandler = require(M3),
	ErrorThrower = new ErrorHandler(
		[
			"wrong params",
			"no path",
			"Item cannot be saved"
		],
		true
	),

	ERROR_WRONG_PARAMS = 0,
	ERROR_NO_PATH = 1,
	ERROR_ITEM_NO_SAVE = 2;

/**
 * Instantiates the Firestore API
 * @param mClient Firestore Client
 * @param collectionType
 * @return {*}
 * @constructor
 */

function FireApiNew(mClient, collectionType) {

	const
		LISTENING = {},
		ISROOT = collectionType === 2;

	if (NIP && NIP.rt) {
		return NIP.rt;
	}

	const
		TAG = "[FirestoreApiSimple]";

	function AError(message, code) {
		return {
			message,
			code: code || -1
		};
	}

	function REJECTOR(reject, error, code) {
		if (typeof error === "string") {
			reject(new AError(error, code));
		}
		reject(new AError(error.message, error.code));
	}

	function unlistenPromise(collectionName) {

		if (LISTENING[collectionName]) {

			try {

				const chanCol = LISTENING[collectionName];
				if (chanCol) {
					chanCol.stop();
					delete LISTENING[collectionName];
				}
				return Promise_resolve.call(PROMISE, collectionName);

			} catch (e) {
				return Promise_reject.call(PROMISE, e);
			}

		} else {
			return Promise_reject.call(PROMISE, new ERROR(collectionName));
		}
	}

	function listenPromise(collectionName, aCondition, orderBy, listener) {
		return new PROMISE((resolve, reject) => {
			try {
				const
					chanCol = mClient.current(collectionType)
						.Listener(
							collectionName,
							(query) => {

								if (ISROOT) {
									query = query.where("channelInfo.id", "==", mClient.getConnected());
								}

								if (aCondition) {
									query = query.where(aCondition[0], aCondition[1], aCondition[2]);
								}

								if (orderBy) {
									if (typeof (orderBy) === "string") {
										query = query.orderBy(orderBy);
									} else if (orderBy.length) {
										query = query.orderBy(orderBy[0], orderBy[1]);
									}
								}

								return query;
							}
						);
				chanCol.start({
					notifyItemAdded: item => listener({
						item,
						added: true
					}),
					notifyItemModified: item => listener({
						item,
						modified: true
					}),
					notifyItemRemoved: item => listener({
						item,
						removed: true
					})
				});

				LISTENING[collectionName] = chanCol;

				resolve(collectionName);
			} catch (e) {
				reject(e);
			}
		});
	}

	function setDocRefPromise(docref, payload, merge) {

		payload = payload ? JSON.parse(JSON.stringify(payload)) : null;

		if (docref) {
			return new PROMISE(((resolve, reject) => {

				function gotDoc(doc) {
					const path = doc._key.path.toString();
					if (D) console.log(TAG, "GET", path);
					if (doc.exists) {
						const data = doc.data();
						data._id = doc.id;
						data._path = path;
						resolve(data);
					} else {
						REJECTOR(reject, path, 404);
					}
				}

				docref
					.set(payload, {merge: !!merge})
					.then((doc) => {
						if (!doc) {
							docref
								.get()
								.then(gotDoc)
								.catch((err) => {
									REJECTOR(reject, err);
								});
						} else {
							gotDoc(doc);
						}
					})
					.catch((err) => {
						REJECTOR(reject, err);
					});

			}));
		}
		return Promise_reject.call(PROMISE, ErrorThrower(ERROR_WRONG_PARAMS));
	}

	function docSetPromise(rawpath, item, merge) {
		if (rawpath && item) {
			return new PROMISE((resolve, reject) => {
				mClient.rdoc(rawpath)
					.set(item, {merge: !!merge})
					.then(() => resolve(true))
					.catch(err => REJECTOR(reject, err));
			});
		}
		return Promise_reject.call(PROMISE, ErrorThrower(ERROR_WRONG_PARAMS));
	}

	function docDelPromise(rawpath) {
		if (rawpath) {
			return new PROMISE((resolve, reject) => {
				mClient.rdoc(rawpath)
					.del(rawpath)
					.then(() => resolve(true))
					.catch((err) => {
						REJECTOR(reject, err);
					});
			});
		}
		return Promise_reject.call(PROMISE, ErrorThrower(ERROR_NO_PATH));

	}

	function getDocRefPromise(docref) {

		if (docref) {
			return new PROMISE(((resolve, reject) => {
				docref
					.get()
					.then((doc) => {
						const
							path = doc._key.path.toString();

						if (D) console.log(TAG, "GET", path);
						if (doc.exists) {
							const data = doc.data();
							data._id = doc.id;
							data._path = path;
							resolve(data);
						} else {
							REJECTOR(reject, path, 404);
						}
					})
					.catch((err) => {
						REJECTOR(reject, err);
					});

			}));
		}
		return Promise_reject.call(PROMISE, ErrorThrower(ERROR_WRONG_PARAMS));


	}

	function addChannelEntityPromise(COLLECTION, entity, datatype, fixedId) {

		if (COLLECTION && entity && (datatype || entity.type)) {
			return new PROMISE(((resolve, reject) => {


				const
					docref = fixedId
						? mClient.current(collectionType)
							.ccol(COLLECTION)
							.doc(fixedId)
						: mClient.current(collectionType)
							.ccol(COLLECTION)
							.doc();

				const
					_path = docref._key.path.toString(),
					_id = docref.id;

				entity.id = docref.id;

				NobjAuth.entity.tag(datatype || entity.type, entity, entity.title);

				entity = JSON.parse(JSON.stringify(entity));
				delete entity._id;
				delete entity._path;

				docref
					.set(entity, {merge: false})
					.then(() => {
						resolve({
							id: _id,
							path: _path
						});
					})
					.catch((err) => {
						REJECTOR(reject, err);
					});

			}));
		}
		return Promise_reject.call(PROMISE, ErrorThrower(ERROR_WRONG_PARAMS));


	}

	function getChannelEntityPromise(COLLECTION, id) {

		return new PROMISE(((resolve, reject) => {
			if (COLLECTION && id) {
				try {
					const
						docref = mClient.current(collectionType)
							.ccol(COLLECTION)
							.doc(id);
					getDocRefPromise(docref)
						.then(resolve)
						.catch((err) => {
							REJECTOR(reject, err);
						});
				} catch (e) {
					REJECTOR(reject, e);
				}
			} else {
				REJECTOR(reject, "wrong params", 400);
			}
		}));
	}

	function getChannelDocumentPromise() {

		return new PROMISE(((resolve, reject) => {
			try {
				const
					docref = mClient.current(collectionType)
						.cdoc();
				getDocRefPromise(docref)
					.then(resolve)
					.catch((err) => {
						REJECTOR(reject, err);
					});
			} catch (e) {
				REJECTOR(reject, e);
			}
		}));
	}


	function docListenPromise(docref, listener) {
		return new PROMISE((resolve, reject) => {

			try {

				const
					docListener = mClient.current()
						.DocListener(docref);

				docListener.start({
					notifyChange: listener
				});

				resolve(docListener);

			} catch (e) {
				reject(e);
			}
		});
	}


	function setChannelDocumentPromise(payload, merge) {

		return new PROMISE(((resolve, reject) => {
			try {
				const
					docref = mClient.current(collectionType)
						.cdoc();
				setDocRefPromise(docref, payload, merge)
					.then(resolve)
					.catch(err => REJECTOR(reject, err));
			} catch (e) {
				REJECTOR(reject, e);
			}
		}));
	}

	function getServiceDocumentPromise(service) {

		return new PROMISE(((resolve, reject) => {
			try {
				const
					docref = mClient.current(collectionType)
						.sdoc(service);
				getDocRefPromise(docref)
					.then(resolve)
					.catch(err => REJECTOR(reject, err));
			} catch (e) {
				REJECTOR(reject, e);
			}
		}));
	}

	function setServiceDocumentPromise(service, payload, merge) {

		return new PROMISE(((resolve, reject) => {
			try {
				const
					docref = mClient.current(collectionType)
						.sdoc(service);
				setDocRefPromise(docref, payload, merge)
					.then(resolve)
					.catch(err => REJECTOR(reject, err));
			} catch (e) {
				REJECTOR(reject, e);
			}
		}));
	}

	function docGetPromise(path) {
		try {
			return getDocRefPromise(mClient.rdoc(path));
		} catch (e) {
			return Promise_reject.call(PROMISE, e);
		}
	}


	function docCreateIdPromise(channelCollection) {

		if (channelCollection) {
			return new PROMISE(((resolve, reject) => {
				try {
					const doc = mClient.current(collectionType)
							.ccol(channelCollection)
							.doc(),
						path = doc._key.path.toString(),
						{id} = doc;

					resolve({
						id,
						ref: path
					});

				} catch (e) {
					REJECTOR(reject, e);
				}
			}));
		}
		return Promise_reject.call(PROMISE, ErrorThrower(ERROR_WRONG_PARAMS));
	}


	function delTaggedEntityPromise(item) {
		return new PROMISE(((resolve, reject) => {

			const path = item._path;
			if (path) {

				mClient.rdoc(path)
					.delete()
					.then(() => resolve(true))
					.catch(err => REJECTOR(reject, err));
			} else {
				REJECTOR(reject, "no path", 400);
			}
		}));
	}

	function updateTaggedEntityPromise(item, merge) {

		if (item._id && item._path && item._path.endsWith(item._id)) {
			try {

				const
					docref = mClient.rdoc(item._path),
					deep = JSON.parse(JSON.stringify(item));

				delete deep._id;
				delete deep._path;

				return docref.set(deep, {merge: !!merge});

			} catch (e) {
				return Promise_reject.call(PROMISE, e);
			}
		} else {
			return Promise_reject.call(PROMISE, ErrorThrower(ERROR_ITEM_NO_SAVE));
		}
	}

	// noinspection JSUnusedGlobalSymbols
	return {
		listen: listenPromise,
		unlisten: unlistenPromise,
		rdoc: {
			set: docSetPromise,
			del: docDelPromise,
			get: docGetPromise
		},
		ccol: {
			doc: docCreateIdPromise
		},
		cdoc: {
			set: setChannelDocumentPromise,
			get: getChannelDocumentPromise,
			listen: listener => docListenPromise(mClient.current()
				.cdoc(), listener)
		},
		sdoc: {
			set: setServiceDocumentPromise,
			get: getServiceDocumentPromise,
			listen: (service, listener) => docListenPromise(mClient.current()
				.sdoc(service), listener)
		},
		entch: {
			add: addChannelEntityPromise,
			upd: updateTaggedEntityPromise,
			del: delTaggedEntityPromise,
			get: getChannelEntityPromise
		}
	};

}

module.exports = FireApiNew;

});
requireRegister(M3, function (exports, require, module) {
/* global ERROR */

function ERRORHANDLER(errors, noThrow) {
	return (num, doThrow) => {
		const e = new ERROR(errors[num]);
		if (noThrow && !doThrow) return e;
		throw e;
	};
}

module.exports = ERRORHANDLER;

});
requireRegister(M4, function (exports, require, module) {
/* global PROMISE, firebase,  Promise_resolve */
/*
	ext:
		src: "fbk"
		fnm: "Rudolf Pintor"
		ftk: "EAAX0USZATHOMBABhg1k3c926noVcc1Py3RZADDAZAQgKhZBNKC9CIorZAnrkUoAuZCPE6ip9Wfe6EsZBk8cZAUkatesyCfwJfLrQpIddUWo3ZC3x
		uYrAoH84m3I5p9EQWPQTNJTfZA0Rm3ZBLwpTg57MrlHKiweASSQi8ZAgG6kGYSHzHwZDZD"
		FIRE: {apiKey: "AIzaSyDDXJns1Mw-JUuY7_fNssM8c1Y6Zs7Seg4", authDomain: "nobj-quarantune.firebaseapp.com", databaseURL:
		"https://nobj-quarantune.firebaseio.com", projectId: "nobj-quarantune", storageBucket: "nobj-quarantune.appspot.com", …}
	exp: 1585525885954
	iss: "NANO"
	aud: "SOCIAL"
	sub: "1198292656884105"
*/

const
	NobjAuth = require("nobj.auth"),
	FirestoreLoader = require("./nobj.fire.loader"),
	FireApi = require("./nobj.fire.api"),
	FireApiNew = require("./nobj.fire.api.simple");

let
	mInited = false,
	mFireApi = null,

	mFireApiPublic = null,
	mFireApiPrivate = null,
	mFireApiRoot = null;

/**
 * Initializes the module
 * @return {Promise}
 */

function initInternal() {

	return mInited
		? Promise_resolve.call(PROMISE)
		: new PROMISE((resolve, reject) => {

			// noinspection JSUnresolvedFunction
			FirestoreLoader()
				.then(() => {

					try {
						const token = NobjAuth.token(true);

						// Initialize Firebase
						// noinspection JSUnresolvedFunction

						firebase.initializeApp(token.ext.FIRE);
						mInited = true;
						mFireApi = new FireApi(token);

						mFireApiPrivate = new FireApiNew(mFireApi, 0);
						mFireApiPublic = new FireApiNew(mFireApi, 1);
						mFireApiRoot = new FireApiNew(mFireApi, 2);


					} catch (e) {
						reject(e);
						return;
					}
					resolve();
				})
				.catch(reject);
		});
}

/**
 * Initializes the module
 */

function init() {

	return new PROMISE((resolve, reject) => {
		initInternal()
			.then(() => mFireApi.init()
				.then(() => {
					resolve();
				})
				.catch(reject))
			.catch(reject);

	});

}

module.exports = {
	init,
	priv: () => mFireApiPrivate,
	pub: () => mFireApiPublic,
	root: () => mFireApiRoot
};

});
requireRegister(M5, function (exports, require, module) {
/* global D, PROMISE, Promise_resolve */

/* eslint-disable no-underscore-dangle */
function FirestoreLoader() {

	const
		TAG = "[FireLoader]",
		VERSION = "5.2.0",
		FILES = ["firebase-app.js", "firebase-auth.js", "firebase-firestore.js"],
		HOST = "https://www.gstatic.com/firebasejs/" + VERSION;

	const load = (function () {
		// Function which returns a function: https://davidwalsh.name/javascript-functions
		function _load(tag) {
			return function (url) {
				// This promise will be used by Promise.all to determine success or failure
				return new PROMISE(((resolve, reject) => {
					const element = document.createElement(tag);
					let parent = "body";
					let attr = "src";

					// Important success and error for the promise
					element.onload = function () {
						if (D) window.console.log(TAG, "> success loading ", url);
						resolve(url);
					};
					element.onerror = function () {
						if (D) window.console.log(TAG, "> fail loading ", url);
						reject(url);
					};

					// Need to set different attributes depending on tag type
					switch (tag) {
						case "script":
							element.async = true;
							break;
						case "link":
							element.type = "text/css";
							element.rel = "stylesheet";
							attr = "href";
							parent = "head";
						default:
							break;
					}

					// Inject into document to kick off loading
					element[attr] = url;
					document[parent].appendChild(element);
				}));
			};
		}

		return {
			css: _load("link"),
			js: _load("script"),
			img: _load("img")
		};
	}());

	return (window.firebase && window.firebase.firestore)
		? Promise_resolve.call(PROMISE, window.firebase)
		: new PROMISE(((resolve, reject) => {

			load.js(HOST + "/" + FILES[0])
				.then(() => {
					load.js(HOST + "/" + FILES[1])
						.then(() => {
							load.js(HOST + "/" + FILES[2])
								.then(() => {
									if (window.firebase) {
										resolve(window.firebase);
									} else {
										reject("Cannot load firebase libraries");
									}
								})
								.catch(reject);
						})
						.catch(reject);
				})
				.catch(reject);
		}));
}

module.exports = FirestoreLoader;

});

;

})(
    Promise,
    Object.assign,
    Object.keys,
    window.setTimeout,
    window.clearTimeout,
    window.location,
    window.addEventListener,
    document,
    document.body,
    document.documentElement,
    document.documentElement.classList,
    window,
    window.NIPC || null,
    Error
);
})("131b5289ac9efcbc3eb0ffa56aac71b6","f54ffd3ced3a49b03965b1f31b804a4b","7107da7c6b58b6f5636ea5a10987038f","08a3db35c872e45e4d6cea3fe71656b0","5c15c44710328e08e0ede723f7734262","96664545452ee6a544992b9c1216f2c0",0)
